<?php
/**
 * Author: MDA
 * Author URI: https://github.com/DiUnique
 * Author email: info@md-web.ru
 */

chdir ('../../');
require_once "api/Simpla.php";

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    file_put_contents(__DIR__ . '/enot_error.log', date('Y-m-d H:i:s') . ' - callback # enot: Invalid method.' . "\r\n", FILE_APPEND);
    http_response_code(405); // Method Not Allowed
    exit;
}

$signature_header = $_SERVER['HTTP_X_API_SHA256_SIGNATURE'] ? $_SERVER['HTTP_X_API_SHA256_SIGNATURE'] : '';

if (!$signature_header) {
    file_put_contents(__DIR__ . '/enot_error.log', date('Y-m-d H:i:s') . ' - callback # enot: No signature.' . "\r\n", FILE_APPEND);
    exit;
}

$sign = $request_body = file_get_contents('php://input');
file_put_contents(__DIR__ . '/wooenot_payment.log', date('Y-m-d H:i:s') . " - callback # enot: $request_body" . "\r\n", FILE_APPEND);

$request_body = json_decode($request_body, true);

$order_id = explode('_', $request_body['order_id']);
$order_id = (int)$order_id[1];

$simpla = new Simpla();

$order = $simpla->orders->get_order($order_id);

if (!empty($order)) {
    $payment_method = $simpla->payment->get_payment_method( intval($order->payment_method_id) );
    $payment_settings = $simpla->payment->get_payment_settings( $payment_method->id );

    $sign = json_decode($sign, true);
    ksort($sign);
    $sign = json_encode($sign);

    $secret_key = $payment_settings["secret_key2"];
    $calculated_signature = hash_hmac('sha256', $sign, $secret_key);

    // Compare the calculated signature with the signature in the header
    if (!hash_equals($signature_header, $calculated_signature)) {
        file_put_contents(__DIR__ . '/enot_error.log', date('Y-m-d H:i:s') . ' - callback # enot: Invalid signature.' . "\r\n", FILE_APPEND);
        http_response_code(401); // Unauthorized
        exit;
    }

    if (!empty($payment_method)) {
        $err = false;
        $message = "";
        $settings = unserialize($payment_method->settings);

        if (!$err) {
            if ($request_body["amount"] != $order->total_price) {
                $message .= " - неправильная сумма\n";
                $err = true;
            }
            if ($request_body['status'] == 'fail') {
                $message .= " - транзакция отклонена\n";
                $err = true;
            }

            if (!$err && !$order->paid && $request_body['status'] == 'success') {
                $simpla->orders->update_order(intval($order->id), [
                    "paid" => 1,
                ]);
                $simpla->orders->close(intval($order->id));
                $simpla->notify->email_order_user(
                    intval($order->id)
                );
                $simpla->notify->email_order_admin(
                    intval($order->id)
                );
            }
        }

        if ($err) {
            $to = $payment_settings["enotio_email"];

            if (!empty($to)) {
                $message =
                    "Не удалось провести платёж через систему enotio по следующим причинам:\n\n" .
                    $message . "\n";
                $headers =
                    "From: no-reply@" .
                    $_SERVER["HTTP_HOST"] .
                    "\r\n" .
                    "Content-type: text/plain; charset=utf-8 \r\n";
                mail($to, "Ошибка оплаты по заказу {$order->id}", $message, $headers);
            }

            exit($order_id . " | error | " . $message);
        } else {
            exit("YES");
        }
    }
}